@@ -27,28 +27,28 @@ def _process_config(path: Optional[pathlib.Path]) -> Config:
 
     try:
         return Config.load_from_path(path=path)
-    except:  # noqa
-        raise typer.BadParameter("Unable to parse config")
+    except Exception as err:
+        raise typer.BadParameter("Unable to parse config") from err
 
 
 # noinspection PyUnusedLocal
+# pylint: disable=unused-argument
 @app.callback(name="openapi-python-client")
 def cli(
     version: bool = typer.Option(False, "--version", callback=_version_callback, help="Print the version and exit"),
 ) -> None:
     """Generate a Python client from an OpenAPI JSON document"""
-    pass
 
 
-def _print_parser_error(e: GeneratorError, color: str) -> None:
-    typer.secho(e.header, bold=True, fg=color, err=True)
+def _print_parser_error(err: GeneratorError, color: str) -> None:
+    typer.secho(err.header, bold=True, fg=color, err=True)
     typer.echo()
-    if e.detail:
-        typer.secho(e.detail, fg=color, err=True)
+    if err.detail:
+        typer.secho(err.detail, fg=color, err=True)
         typer.echo()
 
-    if isinstance(e, ParseError) and e.data is not None:
-        formatted_data = pformat(e.data)
+    if isinstance(err, ParseError) and err.data is not None:
+        formatted_data = pformat(err.data)
         typer.secho(formatted_data, fg=color, err=True)
 
     typer.echo()
@@ -82,7 +82,7 @@ def handle_errors(errors: Sequence[GeneratorError], fail_on_warning: bool = Fals
         _print_parser_error(err, color)
 
     gh_link = typer.style(
-        "https://github.com/triaxtec/openapi-python-client/issues/new/choose", fg=typer.colors.BRIGHT_BLUE
+        "https://github.com/openapi-generators/openapi-python-client/issues/new/choose", fg=typer.colors.BRIGHT_BLUE
     )
     typer.secho(
         f"If you believe this was a mistake or this tool is missing a feature you need, "
@@ -111,6 +111,7 @@ _meta_option = typer.Option(
 CONFIG_OPTION = typer.Option(None, "--config", help="Path to the config file to use")
 
 
+# pylint: disable=too-many-arguments
 @app.command()
 def generate(
     url: Optional[str] = typer.Option(None, help="A URL to read the JSON from"),
@@ -133,9 +134,9 @@ def generate(
 
     try:
         codecs.getencoder(file_encoding)
-    except LookupError:
+    except LookupError as err:
         typer.secho("Unknown encoding : {}".format(file_encoding), fg=typer.colors.RED)
-        raise typer.Exit(code=1)
+        raise typer.Exit(code=1) from err
 
     config = _process_config(config_path)
     errors = create_new_client(
@@ -149,6 +150,7 @@ def generate(
     handle_errors(errors, fail_on_warning)
 
 
+# pylint: disable=too-many-arguments
 @app.command()
 def update(
     url: Optional[str] = typer.Option(None, help="A URL to read the JSON from"),
@@ -171,9 +173,9 @@ def update(
 
     try:
         codecs.getencoder(file_encoding)
-    except LookupError:
+    except LookupError as err:
         typer.secho("Unknown encoding : {}".format(file_encoding), fg=typer.colors.RED)
-        raise typer.Exit(code=1)
+        raise typer.Exit(code=1) from err
 
     config = _process_config(config_path)
     errors = update_existing_client(
